<?php

require __DIR__ . '/vendor/autoload.php';

use PayPalCheckoutSdk\Core\PayPalHttpClient;
use PayPalCheckoutSdk\Core\ProductionEnvironment;
use PayPalCheckoutSdk\Core\SandboxEnvironment;
use PayPalCheckoutSdk\Orders\OrdersCaptureRequest;
use PayPalCheckoutSdk\Orders\OrdersGetRequest;
use PayPalCheckoutSdk\Payments\CapturesRefundRequest;

class WPBS_PayPal_API
{
    public static function keys()
    {
        $settings = get_option('wpbs_settings', array());
        $paypal_api = get_option('wpbs_paypal_api', array());

        if ((isset($settings['payment_paypal_sandbox']) && $settings['payment_paypal_sandbox'] == 'on')) {
            return array(
                'environment' => 'sandbox',
                'client_id' => isset($paypal_api['payment_paypal_sandbox_api_client_id']) ? trim($paypal_api['payment_paypal_sandbox_api_client_id']) : '',
                'secret' => isset($paypal_api['payment_paypal_sandbox_api_secret']) ? trim($paypal_api['payment_paypal_sandbox_api_secret']) : '',
            );
        } else {
            return array(
                'environment' => 'live',
                'client_id' => isset($paypal_api['payment_paypal_live_api_client_id']) ? trim($paypal_api['payment_paypal_live_api_client_id']) : '',
                'secret' => isset($paypal_api['payment_paypal_live_api_secret']) ? trim($paypal_api['payment_paypal_live_api_secret']) : '',
            );
        }
    }
}

class WPBS_PayPal_Client
{
    /**
     * Returns PayPal HTTP client instance with environment that has access
     * credentials context. Use this instance to invoke PayPal APIs, provided the
     * credentials have access.
     */
    public static function client()
    {
        return new PayPalHttpClient(self::environment());
    }

    /**
     * Set up and return PayPal PHP SDK environment with PayPal access credentials.
     * This sample uses SandboxEnvironment. In production, use ProductionEnvironment.
     */
    public static function environment()
    {

        $api = WPBS_PayPal_API::keys();

        if ($api['environment'] == 'sandbox') {
            return new SandboxEnvironment($api['client_id'], $api['secret']);
        } elseif ($api['environment'] == 'live') {
            return new ProductionEnvironment($api['client_id'], $api['secret']);
        }

    }
}

/**
 * Get order details from PayPal
 *
 */
class WPBS_PayPal_GetOrder
{
    public static function getOrder($orderId)
    {

        $client = WPBS_PayPal_Client::client();

        try {
            $response = $client->execute(new OrdersGetRequest($orderId));
            return array(
                'success' => true,
                'data' => $response,
            );
        } catch (Exception $e) {
            return array(
                'success' => false,
                'error' => $e->getMessage(),
            );
        }
    }
}

/**
 * Get order details from PayPal
 *
 */
class WPBS_PayPal_RefundOrder
{
    public static function refundOrder($captureId, $amount, $currency)
    {

        $client = WPBS_PayPal_Client::client();

        try {
            $request = new CapturesRefundRequest($captureId);

            $request->body = array(
                'amount' => array(
                    'value' => $amount,
                    'currency_code' => $currency,
                ),
            );

            return array(
                'success' => true,
                'response' => $client->execute($request)
            );
        } catch (Exception $e) {
            return array(
                'success' => false,
                'error' => $e->getMessage(),
            );
        }
    }
}

/**
 * Capture Order
 *
 */
class WPBS_PayPal_CaptureOrder
{

    public static function captureOrder($orderId)
    {
        try {

            $request = new OrdersCaptureRequest($orderId);
            $client = WPBS_PayPal_Client::client();
            $response = $client->execute($request);

            return array(
                'success' => true,
                'data' => $response,
            );

        } catch (Exception $e) {

            $error = json_decode($e->getMessage(), true);

            return array(
                'success' => false,
                'error' => $e->getMessage(),
            );
        }

    }
}
